<?php

// Erstellt aus JSON-Daten von programs.json und incentives.json eine neue relationale Datenbank
// mit nur den benoetigten Daten zu Kategorien, Programmen und Incentives
// in Form von PHP-Arrays.

// Diese Datei wird automatisch von ZanoxEngine_init.php aufgerufen.

// Die fertige Datenbank ist wie folgt in 4 einzelne PHP-Arrays aufgeteilt (hier: wesentliche Funktionen):

// $CatID_from_CatName[]:  Parameter: Kategorie-Name  ->  Ausgabe: Kategorie-ID
// $ProgIDs_from_CatID[]:  Parameter: Kategorie-ID  ->  Ausgabe: Array mit den zugehoerigen Programm-IDs
// $ProgInfos_from_ProgID[]:  Parameter: Programm-ID  ->  Ausgabe: Array mit den zugehoerigen Programm-Infos
// $Incentives_from_ProgID[]:  Parameter: Programm-ID  ->  Ausgabe: Array mit den zugehoerigen Coupon-Daten

// Die Datenbank kann von jeder PHP-Datei aus benutzt werden, wenn sie zuerst wie folgt eingelesen wird:

/*

include 'ZanoxEngine.php';

*/


// Alle Daten aus programs.json in $programs_array[] einlesen:

$programs_array = json_decode(deBOM(file_get_contents('programs.json')), true);


// Alle Programme aus $programs_array[] nach Programm-Infos und Kategorie-Daten durchgehen:

$CatID_from_CatName = array();
$ProgIDs_from_CatID = array();
$ProgInfos_from_ProgID = array();
$Incentives_from_ProgID = array();

foreach ($programs_array['programItems']['programItem'] as $program)  // Alle Programme durchgehen fuer Programm-Infos und Kategorien...
   {
    $ProgramID = $program['@id'];
 // u8h() dient der Handhabung von UTF-8-Multibyte-Zeichen; deCDATA() entfernt CDATA-Tags...
    $ProgInfos_from_ProgID[$ProgramID]['name'] = u8h($program['name']);
    $ProgInfos_from_ProgID[$ProgramID]['description'] = u8h($program['description']);
    $ProgInfos_from_ProgID[$ProgramID]['url'] = $program['url'];
    $ProgInfos_from_ProgID[$ProgramID]['image'] = $program['image'];

 // $ProgInfos_from_ProgID[$ProgramID]['descriptionLocal'] = u8h(deCDATA($program['descriptionLocal']));  // Weitere Felder koennen hier uebernommen werden...

    $Incentives_from_ProgID[$ProgramID] = array();  // Programm-ID als Key zu $Incentives_from_ProgID[] hinzufuegen

    if (!is_array($program['categories']['0']['category'])) continue;  // Saemtliche Kategorie-Daten fehlen!

    $categories = $program['categories']['0']['category'];

    reset($categories);
    if (!is_array($categories[key($categories)]))  // Nur eine Kategorie ist angegeben
       {
        $CatID_from_CatName[u8h($categories['$'])] = $categories['@id'];
        $ProgIDs_from_CatID[$categories['@id']]['name'] = u8h($categories['$']);
        $ProgIDs_from_CatID[$categories['@id']]['Programs'][] = $ProgramID;
       }
    else  // Mehrere Kategorien sind angegeben
       {
        foreach ($categories as $category)
           {
            $CatID_from_CatName[u8h($category['$'])] = $category['@id'];
            $ProgIDs_from_CatID[$category['@id']]['name'] = u8h($category['$']);
            $ProgIDs_from_CatID[$category['@id']]['Programs'][] = $ProgramID;
           }
       }
   }

$programs_array = NULL;

// Array $CatID_from_CatName[] alphabetisch aufsteigend nach Kategorie-Namen ordnen:
uksort($CatID_from_CatName, 'strcasecmp_uh');

// Array $CatID_from_CatName[] in Datei CatID_from_CatName.dat speichern:
file_put_contents('CatID_from_CatName.dat', serialize($CatID_from_CatName));
$CatID_from_CatName = NULL;

// 'Programs'-Sub-Arrays in Array $ProgIDs_from_CatID[] alphabetisch aufsteigend nach Programm-Firmen-Namen ordnen:
function namecomp($id1, $id2)  // Verwandt fuer usort() und uksort() nach Firmen-Namen aus $ProgInfos_from_ProgID[]
   {
    global $ProgInfos_from_ProgID;
    if (isset($ProgInfos_from_ProgID[$id1]) && isset($ProgInfos_from_ProgID[$id2]))
       {
        return strcasecmp_uh($ProgInfos_from_ProgID[$id1]['name'], $ProgInfos_from_ProgID[$id2]['name']);
       }
    else
       {
        return 0;
       }
   }
foreach ($ProgIDs_from_CatID as $CatID => $progs)   // Direktes Sortieren per Referenz funktionierte unter PHP 4 nicht
   {
    usort($progs['Programs'], 'namecomp');
    $ProgIDs_from_CatID[$CatID]['Programs'] = $progs['Programs'];
   }

// Array $ProgIDs_from_CatID[] alphabetisch aufsteigend nach Kategorie-Namen ordnen:
function snamecomp($id1, $id2) { return strcasecmp_uh($id1['name'], $id2['name']); }  // Verwandt fuer uasort() (hier sowie weiter unten):
uasort($ProgIDs_from_CatID, 'snamecomp');

// Array $ProgIDs_from_CatID[] in Datei ProgIDs_from_CatID.dat speichern:
file_put_contents('ProgIDs_from_CatID.dat', serialize($ProgIDs_from_CatID));
$ProgIDs_from_CatID = NULL;


// Alle Daten aus incentives.json in $incentives_array[] einlesen:

$incentives_array = json_decode(deBOM(file_get_contents('incentives.json')), true);


// Alle Incentives aus $incentives_array[] nach Coupon-Incentives-Daten durchgehen:

foreach ($incentives_array['incentiveItems']['incentiveItem'] as $incentive)  // Alle Incentives durchgehen fuer Coupon-Daten...
   {
    if ($incentive['incentiveType']!='coupons') continue;  // Incentive ist kein Coupon, daher zum naechsten! - Auskommentieren, um ALLE Typen von Incentives zu verwenden.

    $ProgramID = $incentive['program']['@id'];
 // u8h() dient der Handhabung von UTF-8-Multibyte-Zeichen...
    if (!isset($ProgInfos_from_ProgID[$ProgramID]))  // Ist ID-Key noch nicht in jener Liste, neuen Datensatz anlegen
       {
        if (isset($incentive['program']['$']))
           {
            $ProgInfos_from_ProgID[$ProgramID]['name'] = u8h($incentive['program']['$']);
           }
        else
           {
            $ProgInfos_from_ProgID[$ProgramID]['name'] = '';
           }
        $ProgInfos_from_ProgID[$ProgramID]['description'] = '';
        $ProgInfos_from_ProgID[$ProgramID]['url'] = '';
        $ProgInfos_from_ProgID[$ProgramID]['image'] = '';
       }

    $idx = 0;
    if (isset($Incentives_from_ProgID[$ProgramID])) $idx = count($Incentives_from_ProgID[$ProgramID]);  // isset() nur zur Sicherheit

    $Incentives_from_ProgID[$ProgramID][$idx]['id'] = $incentive['@id'];
    $Incentives_from_ProgID[$ProgramID][$idx]['name'] = u8h($incentive['name']);
    $Incentives_from_ProgID[$ProgramID][$idx]['startDate'] = fmtDate($incentive['startDate'], $DateFormat);
    $Incentives_from_ProgID[$ProgramID][$idx]['startTime'] = fmtTime($incentive['startDate'], $TimeFormat);
    if (isset($incentive['endDate']))
       {
        $Incentives_from_ProgID[$ProgramID][$idx]['endDate'] = fmtDate($incentive['endDate'], $DateFormat);  // Feld 'endDate' vorhanden...
        $Incentives_from_ProgID[$ProgramID][$idx]['endTime'] = fmtTime($incentive['endDate'], $TimeFormat);
       }
    else
       {
        $Incentives_from_ProgID[$ProgramID][$idx]['endDate'] = '';  // Feld 'endDate' NICHT vorhanden...
        $Incentives_from_ProgID[$ProgramID][$idx]['endTime'] = '';
       }
    if (isset($incentive['couponCode']))
       {
        $Incentives_from_ProgID[$ProgramID][$idx]['couponCode'] = u8h($incentive['couponCode']);  // Feld 'couponCode' vorhanden
       }
    else
       {
        $Incentives_from_ProgID[$ProgramID][$idx]['couponCode'] = '';  // Feld 'couponCode' NICHT vorhanden
       }
    if ($incentive['newCustomerOnly']=='1')  // Sicherstellen, dass 'newCustomerOnly' TRUE oder FALSE sein wird...
       {
        $Incentives_from_ProgID[$ProgramID][$idx]['newCustomerOnly'] = true;
       }
    else
       {
        $Incentives_from_ProgID[$ProgramID][$idx]['newCustomerOnly'] = false;
       }

 // $Incentives_from_ProgID[$ProgramID][$idx]['...'] = u8h($incentive['...']);  // Weitere Felder koennen hier uebernommen werden...

    $incentive_tr = $incentive['admedia']['admediumItem']['trackingLinks'];

    if (is_array($incentive_tr))  // Coupon-URL und -Bild nur abfragen, wenn entspr. Unterstruktur auch vorhanden ist, sonst Typen-Fehler
       {
        $Incentives_from_ProgID[$ProgramID][$idx]['url'] = $incentive_tr['trackingLink'][0]['ppc'];
        $Incentives_from_ProgID[$ProgramID][$idx]['image'] = $incentive_tr['trackingLink'][0]['ppv'];
       }
    else
       {
        $Incentives_from_ProgID[$ProgramID][$idx]['url'] = '';
        $Incentives_from_ProgID[$ProgramID][$idx]['image'] = '';
       }
   }

$incentives_array = NULL;

// Array $ProgInfos_from_ProgID[] alphabetisch aufsteigend nach Programm-Firmen-Namen ordnen:
uasort($ProgInfos_from_ProgID, 'snamecomp');

// Array $ProgInfos_from_ProgID[] in Datei ProgInfos_from_ProgID.dat speichern:
file_put_contents('ProgInfos_from_ProgID.dat', serialize($ProgInfos_from_ProgID));

// Array $Incentives_from_ProgID[] alphabetisch aufsteigend nach Programm-Firmen-Namen ordnen:
uksort($Incentives_from_ProgID, 'namecomp');

$ProgInfos_from_ProgID = NULL;

// Array $Incentives_from_ProgID[] in Datei Incentives_from_ProgID.dat speichern:
file_put_contents('Incentives_from_ProgID.dat', serialize($Incentives_from_ProgID));
$Incentives_from_ProgID = NULL;


print("- Verarbeitung abgeschlossen! -<br>\r\n");

?>
